@@ -60,10 +60,10 @@ class TreeItemModelTest(unittest.TestCase):
         t1_root_child1 = TreeItem(title='child1', tree=t1, parent=t1_root, url='/about/')
         t1_root_child1.save(force_insert=True)
 
-        t1_root_child2 = TreeItem(title='child2', tree=t1, parent=t1_root, url='articles-list', urlaspattern=True)
+        t1_root_child2 = TreeItem(title='child2', tree=t1, parent=t1_root, url='articles_list', urlaspattern=True)
         t1_root_child2.save(force_insert=True)
 
-        t1_root_child2_sub1 = TreeItem(title='subchild1', tree=t1, parent=t1_root_child2, url='articles-detailed art_id', urlaspattern=True)
+        t1_root_child2_sub1 = TreeItem(title='subchild1', tree=t1, parent=t1_root_child2, url='articles_detailed art_id', urlaspattern=True)
         t1_root_child2_sub1.save(force_insert=True)
 
         t1_root_child2_sub2 = TreeItem(title='subchild2', tree=t1, parent=t1_root_child2, url='/not_articles/10/')
@@ -90,6 +90,7 @@ class TreeItemModelTest(unittest.TestCase):
 
         cls.t2 = t2
         cls.t2_root1 = t2_root1
+        
         cls.t2_root2 = t2_root2
         cls.t2_root3 = t2_root3
 
@@ -113,19 +114,22 @@ class TreeItemModelTest(unittest.TestCase):
         self.assertRaises(SiteTreeError, self.sitetree.menu, 'tree1', 'trunk', context)
 
     def test_menu(self):
-        menu = self.sitetree.menu('tree1', 'trunk', get_mock_context(path='/'))
+        menu = self.sitetree.menu('tree1', 'trunk', get_mock_context(path='/about/'))
         self.assertEqual(len(menu), 1)
         self.assertEqual(menu[0].id, self.t1_root.id)
-        self.assertEqual(menu[0].is_current, True)
+        self.assertEqual(menu[0].is_current, False)
         self.assertEqual(menu[0].depth, 0)
         self.assertEqual(menu[0].has_children, True)
+        self.assertEqual(menu[0].in_current_branch, True)
 
         menu = self.sitetree.menu('tree2', 'trunk', get_mock_context(path='/sub/'))
         self.assertEqual(len(menu), 2)
         self.assertEqual(menu[0].id, self.t2_root1.id)
         self.assertEqual(menu[1].id, self.t2_root2.id)
         self.assertEqual(menu[0].is_current, False)
+        self.assertEqual(menu[0].in_current_branch, False)
         self.assertEqual(menu[1].is_current, True)
+        self.assertEqual(menu[1].in_current_branch, True)
         self.assertEqual(menu[0].depth, 0)
         self.assertEqual(menu[1].depth, 0)
         self.assertEqual(menu[0].has_children, False)
@@ -138,7 +142,7 @@ class TreeItemModelTest(unittest.TestCase):
 
         self.assertEqual(bc1[0].id, self.t1_root.id)
         self.assertEqual(bc1[1].id, self.t1_root_child2.id)
-        self.assertEqual(bc1[1].url_resolved, '#unresolved')
+        self.assertEqual(bc1[1].url_resolved, '/articles/')
         self.assertEqual(bc1[2].id, self.t1_root_child2_sub2.id)
 
         self.assertEqual(bc1[0].is_current, False)
@@ -153,6 +157,13 @@ class TreeItemModelTest(unittest.TestCase):
         self.assertEqual(bc1[1].depth, 1)
         self.assertEqual(bc1[2].depth, 2)
 
+    def test_page_title(self):
+        title = self.sitetree.get_current_page_title('tree1', get_mock_context(path='/articles/'))
+        self.assertEqual(title, self.t1_root_child2.title)
+
+        title = self.sitetree.get_current_page_title('tree1', get_mock_context(path='/not_articles/'))
+        self.assertEqual(title, '')
+
     def test_sitetree(self):
         st1 = self.sitetree.tree('tree1', get_mock_context(path='/articles/'))
         self.assertEqual(len(st1), 1)
